"""
SpaceCutter Lightning
=====================

SpaceCutter Lightning is a PyTorch Lightning implementation of the AscensionCallback
from SpaceCutter.

"""
from .callback import ClipCutpoints

__all__ = [
    "ClipCutpoints",
]
